Crate objc2_video_subscriber_account

Crate objc2_video_subscriber_account 

Bindings to the VideoSubscriberAccount framework

See Apple’s docs and the general docs on framework crates for more information.

Structs

VSAccountAccessStatusVSAccountManager
Represents the current state of the application’s access to the user’s subscription information.
VSAccountApplicationProviderVSAccountApplicationProvider
An object which provides an account provider to be added to the list of providers in your application.
VSAccountManagerVSAccountManager
A VSAccountManager instance coordinates access to a subscriber’s account.
VSAccountManagerResultVSAccountManagerResult
Represents an in-flight request to an account manger.
VSAccountMetadataVSAccountMetadata
A collection of information about a subscriber’s account.
VSAccountMetadataRequestVSAccountMetadataRequest
Specifies which information the app wants to obtain about the subscriber’s account. You should only request the information you need to fulfill your contractual obligations.
VSAccountProviderResponseVSAccountProviderResponse
A value object that encapsulates the response given by an account provider.
VSAppleSubscriptionVSAppleSubscription
Apple’s documentation
VSAutoSignInAuthorizationVSAutoSignInAuthorization
Auto sign in authorization state.
VSAutoSignInTokenVSAutoSignInToken
Apple’s documentation
VSAutoSignInTokenUpdateContextVSAutoSignInTokenUpdateContext
Context object used to update the auto sign in token. This object has to be obtained through a user consent flow using -[VSUserAccountManager requestAutoSignInAuthorizationWithCompletionHandler:], then it is passed to -[VSUserAccountManager updateAutoSignInToken:updateContext:completionHandler:]
VSErrorCodeVideoSubscriberAccountErrors
Apple’s documentation
VSOriginatingDeviceCategoryVSUserAccount
Apple’s documentation
VSSubscriptionDeprecatedVSSubscription
A VSSubscription instance describes the extent to which a subscriber has access to content.
VSSubscriptionAccessLevelDeprecatedVSSubscription
Describes the level of access to content.
VSSubscriptionRegistrationCenterDeprecatedVSSubscriptionRegistrationCenter
VSSubscriptionRegistrationCenter stores subscription information.
VSUserAccountVSUserAccount
Apple’s documentation
VSUserAccountManagerVSUserAccountManager
Apple’s documentation
VSUserAccountQueryOptionsVSUserAccountManager
Apple’s documentation
VSUserAccountTypeVSUserAccount
Apple’s documentation

Statics

VSAccountProviderAuthenticationSchemeAPIVSAccountProviderResponse
The identifier for responses that use any authentication protocol.
VSAccountProviderAuthenticationSchemeSAMLVSAccountProviderResponse
The authentication scheme for responses that use the SAML protocol.
VSCheckAccessOptionPromptVSAccountManager
A boolean indicating whether the user may be prompted to grant access.
VSErrorDomainVideoSubscriberAccountErrors
The domain of all errors returned by VideoSubscriberAccount framework.
VSErrorInfoKeyAccountProviderResponseVideoSubscriberAccountErrors
A key that can be used to obtain the account provider’s response object from an error user info dictionary.
VSErrorInfoKeySAMLResponseVideoSubscriberAccountErrors
A key that can be used to obtain the subscription provider’s SAML response string from an error user info dictionary.
VSErrorInfoKeySAMLResponseStatusVideoSubscriberAccountErrors
A key that can be used to obtain the subscription provider’s SAML status code string from an error user info dictionary.
VSErrorInfoKeyUnsupportedProviderIdentifierVideoSubscriberAccountErrors
A key that can be used to obtain the identifier string of the user’s unsupported subscription provider from an error user info dictionary.
VSOpenTVProviderSettingsURLStringVSAccountManager
Apple’s documentation

Traits

VSAccountManagerDelegateVSAccountManager
A VSAccountManager instance coordinates access to a subscriber’s account.

Type Aliases

VSAccountProviderAuthenticationSchemeVSAccountProviderResponse
An opaque protocol name, to be coordinated with specific account providers.
VSCheckAccessOptionVSAccountManager
Options that may be provided when checking access status.