Bindings to the VideoSubscriberAccount framework
See Apple’s docs and the general docs on framework crates for more information.
Structs
- VSAccount
Access Status VSAccountManager - Represents the current state of the application’s access to the user’s subscription information.
- VSAccount
Application Provider VSAccountApplicationProvider - An object which provides an account provider to be added to the list of providers in your application.
- VSAccount
Manager VSAccountManager - A VSAccountManager instance coordinates access to a subscriber’s account.
- VSAccount
Manager Result VSAccountManagerResult - Represents an in-flight request to an account manger.
- VSAccount
Metadata VSAccountMetadata - A collection of information about a subscriber’s account.
- VSAccount
Metadata Request VSAccountMetadataRequest - Specifies which information the app wants to obtain about the subscriber’s account. You should only request the information you need to fulfill your contractual obligations.
- VSAccount
Provider Response VSAccountProviderResponse - A value object that encapsulates the response given by an account provider.
- VSApple
Subscription VSAppleSubscription - Apple’s documentation
- VSAuto
Sign InAuthorization VSAutoSignInAuthorization - Auto sign in authorization state.
- VSAuto
Sign InToken VSAutoSignInToken - Apple’s documentation
- VSAuto
Sign InToken Update Context VSAutoSignInTokenUpdateContext - Context object used to update the auto sign in token.
This object has to be obtained through a user consent flow using
-[VSUserAccountManager requestAutoSignInAuthorizationWithCompletionHandler:], then it is passed to-[VSUserAccountManager updateAutoSignInToken:updateContext:completionHandler:] - VSError
Code VideoSubscriberAccountErrors - Apple’s documentation
- VSOriginating
Device Category VSUserAccount - Apple’s documentation
- VSSubscription
Deprecated VSSubscription - A VSSubscription instance describes the extent to which a subscriber has access to content.
- VSSubscription
Access Level Deprecated VSSubscription - Describes the level of access to content.
- VSSubscription
Registration Center Deprecated VSSubscriptionRegistrationCenter - VSSubscriptionRegistrationCenter stores subscription information.
- VSUser
Account VSUserAccount - Apple’s documentation
- VSUser
Account Manager VSUserAccountManager - Apple’s documentation
- VSUser
Account Query Options VSUserAccountManager - Apple’s documentation
- VSUser
Account Type VSUserAccount - Apple’s documentation
Statics
- VSAccount
Provider ⚠Authentication SchemeAPI VSAccountProviderResponse - The identifier for responses that use any authentication protocol.
- VSAccount
Provider ⚠Authentication SchemeSAML VSAccountProviderResponse - The authentication scheme for responses that use the SAML protocol.
- VSCheck
Access ⚠Option Prompt VSAccountManager - A boolean indicating whether the user may be prompted to grant access.
- VSError
Domain ⚠VideoSubscriberAccountErrors - The domain of all errors returned by VideoSubscriberAccount framework.
- VSError
Info ⚠KeyAccount Provider Response VideoSubscriberAccountErrors - A key that can be used to obtain the account provider’s response object from an error user info dictionary.
- VSError
Info ⚠KeySAML Response VideoSubscriberAccountErrors - A key that can be used to obtain the subscription provider’s SAML response string from an error user info dictionary.
- VSError
Info ⚠KeySAML Response Status VideoSubscriberAccountErrors - A key that can be used to obtain the subscription provider’s SAML status code string from an error user info dictionary.
- VSError
Info ⚠KeyUnsupported Provider Identifier VideoSubscriberAccountErrors - A key that can be used to obtain the identifier string of the user’s unsupported subscription provider from an error user info dictionary.
- VSOpenTV
Provider ⚠SettingsURL String VSAccountManager - Apple’s documentation
Traits
- VSAccount
Manager Delegate VSAccountManager - A VSAccountManager instance coordinates access to a subscriber’s account.
Type Aliases
- VSAccount
Provider Authentication Scheme VSAccountProviderResponse - An opaque protocol name, to be coordinated with specific account providers.
- VSCheck
Access Option VSAccountManager - Options that may be provided when checking access status.